@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 """
-Copyright (c) 2013,2014 Fraunhofer FKIE
+Copyright (c) 2013-2015 Fraunhofer FKIE
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
@@ -11,6 +11,9 @@ are met:
  * Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.
+ * Neither the name of the Fraunhofer organization nor the names of its
+   contributors may be used to endorse or promote products derived from
+   this software without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -38,44 +41,39 @@ def depends(linter):
         info.exec_dep = set([])
         if info.manifest.package_format > 1 and hasattr(info.manifest, "build_export_depends"):
             deps = set([ dep.name for dep in info.manifest.build_export_depends ])
-            if info.env.has_rosdep():
-                for pkg in deps:
-                    if not info.env.is_known_pkg(pkg):
-                        info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="build_export")
+            for pkg in deps:
+                if not info.env.is_known_pkg(pkg):
+                    if info.env.ok: info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="build_export")
             info.export_dep.update(deps)
         if info.manifest.package_format > 1 and hasattr(info.manifest, "buildtool_export_depends"):
             deps = set([ dep.name for dep in info.manifest.buildtool_export_depends ])
-            if info.env.has_rosdep():
-                for pkg in deps:
-                    if not info.env.is_known_pkg(pkg):
-                        info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="buildtool_export")
+            for pkg in deps:
+                if not info.env.is_known_pkg(pkg):
+                    if info.env.ok: info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="buildtool_export")
             info.export_dep.update(deps)
         if info.manifest.package_format > 1 and hasattr(info.manifest, "exec_depends"):
             deps = set([ dep.name for dep in info.manifest.exec_depends ])
-            if info.env.has_rosdep():
-                for pkg in deps:
-                    if not info.env.is_known_pkg(pkg):
-                        info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="build_export")
+            for pkg in deps:
+                if not info.env.is_known_pkg(pkg):
+                    if info.env.ok: info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="exec")
             info.exec_dep.update(deps)
         if info.manifest.package_format < 2 and hasattr(info.manifest, "run_depends"):
             deps = set([ dep.name for dep in info.manifest.run_depends ])
             info.export_dep.update(deps)
             info.exec_dep.update(deps)
-            if info.env.has_rosdep():
-                for pkg in deps:
-                    if not info.env.is_known_pkg(pkg):
-                        info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="run")
+            for pkg in deps:
+                if not info.env.is_known_pkg(pkg):
+                    if info.env.ok: info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="run")
         info.test_dep = set([ dep.name for dep in info.manifest.test_depends ])
-        if info.env.has_rosdep():
-            for pkg in info.buildtool_dep:
-                if not info.env.is_known_pkg(pkg):
-                    info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="buildtool")
-            for pkg in info.build_dep:
-                if not info.env.is_known_pkg(pkg):
-                    info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="build")
-            for pkg in info.test_dep:
-                if not info.env.is_known_pkg(pkg):
-                    info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="test")
+        for pkg in info.buildtool_dep:
+            if not info.env.is_known_pkg(pkg):
+                if info.env.ok: info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="buildtool")
+        for pkg in info.build_dep:
+            if not info.env.is_known_pkg(pkg):
+                if info.env.ok: info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="build")
+        for pkg in info.test_dep:
+            if not info.env.is_known_pkg(pkg):
+                if info.env.ok: info.report(ERROR, "UNKNOWN_DEPEND", pkg=pkg, type="test")
         if info.manifest.is_metapackage() and info.build_dep:
             info.report(ERROR, "INVALID_META_DEPEND", type="build")
         if info.manifest.is_metapackage() and info.test_dep:
