@@ -24,6 +24,8 @@ class ChecksMiscTest(unittest.TestCase):
         self.assertEqual([], result)
         result = mock_lint(env, pkg, "project(wrong)", checks=cc.project)
         self.assertEqual([ "PROJECT_NAME" ], result)
+        result = mock_lint(env, pkg, "project(mock) set(my_mock_var ON)", checks=cc.project)
+        self.assertEqual([ "LITERAL_PROJECT_NAME" ], result)
 
     def test_special_vars(self):
         env = create_env()
@@ -54,7 +56,7 @@ class ChecksMiscTest(unittest.TestCase):
     def test_global_vars(self):
         env = create_env()
         pkg = create_manifest("mock")
-        result = mock_lint(env, pkg, "project(mock) option(mock_option test OFF) set(mock_global CACHE STRING)", checks=cc.global_vars)
+        result = mock_lint(env, pkg, "project(mock) option(${PROJECT_NAME}_option test OFF) set(${PROJECT_NAME}_global CACHE STRING)", checks=cc.global_vars)
         self.assertEqual([], result)
         result = mock_lint(env, pkg, "project(mock) set(global CACHE STRING)", checks=cc.global_vars)
         self.assertEqual([ "GLOBAL_VAR_COLLISION" ], result)
