@@ -10,7 +10,7 @@ class CMakeParserTest(unittest.TestCase):
     def parse_all(self, s, var=None, env_var=None, location=None):
         result = []
         ctxt = cmake.ParserContext()
-        for cmd, args, (fname, line, column) in ctxt.parse(s, var=var, env_var=env_var):
+        for cmd, args, arg_tokens, (fname, line, column) in ctxt.parse(s, var=var, env_var=env_var):
             if location is None:
                 result.append( ( cmd, args) )
             elif location == 1:
@@ -54,6 +54,10 @@ class CMakeParserTest(unittest.TestCase):
             self.parse_all('cmd("string that spans\nmultiple lines")'),
             [ ("cmd", [ 'string that spans\nmultiple lines' ]) ]
         )
+        self.assertEqual(
+            self.parse_all('cmd("\\\\"\\")'),
+            [ ("cmd", [ '\\', '"' ]) ]
+        )
 
     def test_macro(self):
         self.assertEqual(
@@ -224,6 +228,14 @@ class CMakeParserTest(unittest.TestCase):
             self.parse_all('cmd("\\"")'),
             [ ("cmd", [ '"' ]) ]
         )
+        self.assertEqual(
+            self.parse_all('cmd(\\")'),
+            [ ("cmd", [ '"' ]) ]
+        )
+        self.assertEqual(
+            self.parse_all('cmd(a\\ b)'),
+            [ ("cmd", [ 'a b' ]) ]
+        )
         self.assertEqual(
             self.parse_all("cmd(ENV{PATH})"),
             [ ("cmd", [ "ENV{PATH}" ]) ]
@@ -249,7 +261,7 @@ class CMakeParserTest(unittest.TestCase):
         )
         self.assertEqual(
             self.parse_all("cmd(${args})", var={ "args" : "one two three"}),
-            [ ("cmd", [ "one", "two", "three" ]) ]
+            [ ("cmd", [ "one two three" ]) ]
         )
         self.assertEqual(
             self.parse_all('cmd("${args}")', var={ "args" : "one;two;three"}),
